import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'package:zwap_design_system/atoms/atoms.dart';

class ZwapRangeSliderState extends ChangeNotifier{

  RangeValues _currentRangeValues = const RangeValues(18, 60);

  void onChange(RangeValues newValues){
    this._currentRangeValues = newValues;
    notifyListeners();
  }

}

class ZwapRangeSlider extends StatelessWidget{

  final String title;

  ZwapRangeSlider({Key? key, required this.title}): super(key: key);

  @override
  Widget build(BuildContext context) {


    return Consumer<ZwapRangeSliderState>(
      builder: (context, provider, child){
        return Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: EdgeInsets.symmetric(vertical: 10),
              child: Row(
                children: [
                  Flexible(
                    flex: 0,
                    fit: FlexFit.tight,
                    child: ZwapText(
                      text: this.title,
                      zwapTextType: ZwapTextType.body1SemiBold,
                      textColor: ZwapColors.neutral800,
                    ),
                  ),
                  Flexible(
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.end,
                      children: [
                        Flexible(
                          child: ZwapText(
                            text: "${provider._currentRangeValues.start.toInt()} - ${provider._currentRangeValues.end.toInt()}",
                            textColor: ZwapColors.neutral600,
                            zwapTextType: ZwapTextType.body1Regular,
                          ),
                          fit: FlexFit.tight,
                          flex: 0,
                        )
                      ],
                    ),
                  )
                ],
              ),
            ),
            Padding(
              padding: EdgeInsets.only(top: 10),
              child: RangeSlider(
                values: provider._currentRangeValues,
                min: 18,
                max: 60,
                divisions: 42,
                activeColor: ZwapColors.primary700,
                inactiveColor: ZwapColors.neutral200,
                labels: RangeLabels(
                  provider._currentRangeValues.start.round().toString(),
                  provider._currentRangeValues.end.round().toString(),
                ),
                onChanged: (RangeValues values) {
                  provider.onChange(values);
                },
              ),
            )
          ],
        );
      }
    );
  }



}