/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';

/// custom dropdown widget to select some element from a list
class ZwapDropDownState extends ChangeNotifier {
  /// The default value to display
  String? dropdownValue;

  bool isOpen = false;

  bool isHover = false;

  /// Selecting new value from the dropdown widget
  void onChangeValue(String? value) {
    this.dropdownValue = value!;
    this.isOpen = false;
    notifyListeners();
  }

  void openDropDown() {
    this.isOpen = true;
    notifyListeners();
  }

  void hoverButton(bool value) {
    this.isHover = value;
    notifyListeners();
  }
}

/// Description: the state for this current widget
class ZwapSelect extends StatelessWidget {
  /// The custom values to display inside this widget
  final List<String> values;

  /// The default value of this dropdown
  final String? defaultValue;

  ZwapSelect({
    Key? key,
    required this.values,
    this.defaultValue,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer<ZwapDropDownState>(builder: (context, provider, child) {
      return InkWell(
        onHover: (bool value) => provider.hoverButton(value),
        onTap: () => provider.openDropDown(),
        child: Container(
            decoration: BoxDecoration(
                color: ZwapColors.shades0,
                border: Border.all(
                    color: provider.isHover
                        ? ZwapColors.primary300
                        : ZwapColors.neutral300),
                borderRadius: BorderRadius.circular(4)),
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: SizedBox(
                width: 150,
                child: DropdownButton<String>(
                  value: provider.dropdownValue ?? this.values.first,
                  iconSize: 25,
                  focusColor: ZwapColors.neutral300,
                  icon: Icon(
                    !provider.isOpen
                        ? Icons.keyboard_arrow_down_rounded
                        : Icons.keyboard_arrow_up_rounded,
                    color: Color(0xFF323232),
                  ),
                  underline: SizedBox(),
                  elevation: 5,
                  isExpanded: true,
                  onChanged: (String? value) => provider.onChangeValue(value),
                  items:
                      this.values.map<DropdownMenuItem<String>>((String value) {
                    return DropdownMenuItem<String>(
                      value: value,
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Flexible(
                            child: ZwapText(
                              text: value,
                              zwapTextType: ZwapTextType.body1Regular,
                              textColor: ZwapColors.shades100,
                            ),
                            fit: FlexFit.tight,
                            flex: 0,
                          ),
                          Flexible(
                            child: Container(),
                            fit: FlexFit.tight,
                            flex: 0,
                          ),
                        ],
                      ),
                    );
                  }).toList(),
                ),
              ),
            )),
      );
    });
  }
}
