/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';

/// Component to rendering an element card with an icon and a text
class ElementCard extends StatelessWidget{

  /// The custom icon
  final IconData icon;

  /// The custom color
  final Color color;

  /// The custom text
  final String text;

  /// Is this card clicked?
  final bool isSelected;

  ElementCard({Key? key,
    required this.icon,
    required this.color,
    required this.text,
    required this.isSelected
  }): super(key: key);

  Widget build(BuildContext context){
    return Container(
      padding: EdgeInsets.all(15),
      decoration: BoxDecoration(
        color: this.isSelected ? ZwapColors.error400 : ZwapColors.shades0,
        borderRadius: BorderRadius.all(Radius.circular(ZwapRadius.cardRadius)),
        border: Border.all(
          color: this.isSelected ? ZwapColors.error400 : ZwapColors.neutral200
        )
      ),
      child: Column(
        children: [
          Padding(
            padding: EdgeInsets.symmetric(vertical: 4),
            child: Icon(
              this.icon,
              color: this.isSelected ? ZwapColors.shades0 : this.color,
              size: 18,
            ),
          ),
          Padding(
            padding: EdgeInsets.symmetric(vertical: 4),
            child: ZwapText(
              text: this.text,
              zwapTextType: ZwapTextType.buttonText,
              textColor: this.isSelected ? ZwapColors.shades0 : this.color,
            ),
          )
        ],
      ),
    );
  }
}