/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:taastrap/taastrap.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';
import 'package:zwap_design_system/molecules/molecules.dart';
import 'package:zwap_utils/zwap_utils.dart';

import '../atom/zwapCard.dart';

class ZwapProfileCard extends StatefulWidget {
  /// The profile card title
  final String title;

  /// Is this profile verified?
  final bool isVerified;

  /// The profile card subTitle
  final String subTitle;

  /// The button text
  final String buttonText;

  /// The callBack function on button click
  final Function() buttonClickCallBack;

  /// The profile color
  final Color profileColor;

  ZwapProfileCard({
    Key? key,
    required this.title,
    required this.subTitle,
    required this.buttonText,
    required this.buttonClickCallBack,
    required this.profileColor,
    this.isVerified = true,
  }) : super(key: key);

  _ZwapProfileCardState createState() => _ZwapProfileCardState();
}

/// Custom profile card with Zwap standard style
class _ZwapProfileCardState extends State<ZwapProfileCard> {
  /// The hover state for the card card type
  ZwapCardType _cardHoverState = ZwapCardType.levelZero;

  /// Handling the hover state on this component
  void onHover(bool isHover) {
    setState(() {
      this._cardHoverState =
          isHover ? ZwapCardType.levelTwo : ZwapCardType.levelZero;
    });
  }

  /// It gets the widget inside the title section
  Widget _getTitleWidget() {
    Widget tmp = ZwapText(
      textColor: ZwapColors.neutral800,
      zwapTextType: ZwapTextType.body2SemiBold,
      text: widget.title,
    );
    return widget.isVerified
        ? Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Flexible(
                flex: 0,
                fit: FlexFit.tight,
                child: Padding(
                  padding: EdgeInsets.only(right: 3),
                  child: tmp,
                ),
              ),
              Flexible(
                  flex: 0,
                  fit: FlexFit.tight,
                  child: Padding(
                    padding: EdgeInsets.only(left: 3),
                    child: Icon(
                      Icons.verified_sharp,
                      color: Color(0xFF42A5F5),
                      size: 16,
                    ),
                  ))
            ],
          )
        : tmp;
  }

  Size _getSizeResponsive() {
    int deviceType = Utils.getIt<Generic>().deviceType();
    if (deviceType == 4) {
      return Size(261, 234);
    } else if (deviceType == 3) {
      return Size(261, 232);
    } else if (deviceType == 2) {
      return Size(143, 143);
    } else if (deviceType == 1) {
      return Size(256, 256);
    } else {
      return Size(245, 245);
    }
  }

  double _getCardColorHeight() {
    int deviceType = Utils.getIt<Generic>().deviceType();
    if (deviceType == 4) {
      return 83;
    } else if (deviceType == 3) {
      return 67;
    } else if (deviceType == 2) {
      return 50;
    } else if (deviceType == 1) {
      return 90;
    } else {
      return 86;
    }
  }

  @override
  Widget build(BuildContext context) {
    Size sizes = this._getSizeResponsive();
    return InkWell(
      onHover: (bool value) => this.onHover(value),
      onTap: () => {},
      child: ZwapCard(
          zwapCardType: ZwapCardType.levelOne,
          childComponent: Column(
            children: [
              Stack(
                children: [
                  Container(
                    decoration: BoxDecoration(
                      color: widget.profileColor,
                      borderRadius: BorderRadius.only(
                          topLeft: Radius.circular(ZwapRadius.defaultRadius),
                          topRight: Radius.circular(ZwapRadius.defaultRadius)),
                    ),
                    height: this._getCardColorHeight(),
                  ),
                  Center(
                    child: Transform.translate(
                      offset: Offset(0, 25),
                      child: ZwapAvatar(
                        imagePath: "assets/images/placeholders/boy.png",
                        size: 40,
                      ),
                    ),
                  )
                ],
              ),
              Center(
                child: Column(
                  children: [
                    Padding(
                      padding: EdgeInsets.only(top: 40),
                      child: this._getTitleWidget(),
                    ),
                    Padding(
                      padding: EdgeInsets.only(bottom: 6),
                      child: ZwapText(
                        text: widget.subTitle,
                        zwapTextType: ZwapTextType.captionRegular,
                        textColor: ZwapColors.neutral500,
                      ),
                    ),
                  ],
                ),
              ),
              Center(
                child: Padding(
                  padding: EdgeInsets.symmetric(horizontal: 20, vertical: 6),
                  child: ZwapButton(
                    onPressedCallBack: () {},
                    zwapButtonContentType: ZwapButtonContentType.noIcon,
                    zwapButtonStatus: ZwapButtonStatus.defaultStatus,
                    zwapButtonType: ZwapButtonType.primary,
                    text: "Vedi profilo",
                    height: 40,
                    width: 50,
                  ),
                ),
              )
            ],
          )),
    );
  }
}
