/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/atoms/atoms.dart';
import 'package:zwap_design_system/molecules/molecules.dart';

/// It handles the state provider for this tabBar
class ZwapSecondaryTabBarState extends ChangeNotifier {
  /// The items inside the tabBar menu
  final List<String> items;

  /// The current selected item
  late String currentSelected;

  ZwapSecondaryTabBarState({required this.items}) {
    assert(this.items.length == 2,
        "This type of tab bar must have a max of 2 items");
    this.currentSelected = this.items.first;
  }

  /// Handle change inside this tabBar items
  void onChange(String newKey) {
    this.currentSelected = newKey;
    notifyListeners();
  }
}

/// secondary tab bar
class ZwapSecondaryTabBar extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Consumer<ZwapSecondaryTabBarState>(
        builder: (builder, provider, child) {
      return Container(
        decoration: BoxDecoration(
            color: ZwapColors.neutral200,
            borderRadius: BorderRadius.all(Radius.circular(5))),
        child: Padding(
          padding: EdgeInsets.all(ZwapRadius.defaultRadius),
          child: Row(
            children: [
              Expanded(
                child: Padding(
                  padding: EdgeInsets.only(right: 4),
                  child: ZwapButton(
                    zwapButtonStatus: ZwapButtonStatus.defaultStatus,
                    zwapButtonContentType: ZwapButtonContentType.noIcon,
                    zwapButtonType:
                        provider.currentSelected == provider.items[0]
                            ? ZwapButtonType.secondary
                            : ZwapButtonType.flat,
                    text: provider.items[0],
                    onPressedCallBack: () =>
                        provider.onChange(provider.items[0]),
                    textColor: provider.currentSelected == provider.items[0]
                        ? ZwapColors.neutral700
                        : ZwapColors.neutral500,
                  ),
                ),
              ),
              Expanded(
                child: Padding(
                  padding: EdgeInsets.only(left: 4),
                  child: ZwapButton(
                    zwapButtonStatus: ZwapButtonStatus.defaultStatus,
                    zwapButtonContentType: ZwapButtonContentType.noIcon,
                    zwapButtonType:
                        provider.currentSelected == provider.items[1]
                            ? ZwapButtonType.secondary
                            : ZwapButtonType.flat,
                    text: provider.items[1],
                    onPressedCallBack: () =>
                        provider.onChange(provider.items[1]),
                    textColor: provider.currentSelected == provider.items[1]
                        ? ZwapColors.neutral700
                        : ZwapColors.neutral500,
                  ),
                ),
              )
            ],
          ),
        ),
      );
    });
  }
}
